import { DragModal, DragModalTitle, getComputedHeight, useDragSize } from '@/components/a/drag-modal/index.tsx';
import { useChatStore } from '../store';
import { useShallow } from 'zustand/shallow';
import { ChatSettingList } from './List';

export const ChatModelSettingDialog = () => {
  const { showChatSetting, setShowChatSetting, setModelId, modelId } = useChatStore(
    useShallow((state) => ({
      showChatSetting: state.showChatSetting,
      setShowChatSetting: state.setShowChatSetting,
      setModelId: state.setModelId,
      modelId: state.modelId,
    })),
  );
  const computedHeight = getComputedHeight();
  if (!showChatSetting) {
    return null;
  }
  const dragSize = useDragSize();
  return (
    <DragModal
      focus={modelId === 'chat-model-setting'}
      title={
        <DragModalTitle
          title='Chat Models Setting'
          onClose={() => setShowChatSetting(false)}
          onClick={() => {
            setModelId('chat-model-setting');
          }}
        />
      }
      content={
        <div className='w-full h-full p-2 overflow-y-auto scrollbar'>
          <ChatSettingList />
        </div>
      }
      {...dragSize}
    />
  );
};
