import { useHomeStore } from '../store';
import { Modal } from '@/components/a/modal';

import { Controller, useForm } from 'react-hook-form';
import { Button } from '@/components/a/button';
import { useEffect } from 'react';
import { customAlphabet } from 'nanoid';
import { toast } from 'react-toastify';
import { uploadFile } from './upload-file';
import { RefreshCcw } from 'lucide-react';
import { queryApp } from '../store';
import { Input } from '@/components/a/input';
import { Tooltip } from '@/components/a/tooltip';

export const nanoid = customAlphabet('abcdefghijklmnopqrstuvwxyz', 10);
export const UploadModal = () => {
  const { appKey, version, filename, openUploadModal, text, setOpenUploadModal, setAppKey, setVersion, setFilename, setOpenSuccessModal } = useHomeStore();
  const { control, handleSubmit, reset, setValue } = useForm();
  // const { publishVersion } = useAppVersionStore(useShallow((state) => ({ publishVersion: state.publishVersion })));
  useEffect(() => {
    if (openUploadModal) {
      reset({ appKey: appKey || randomAppKey(), version: version || '1.0.0', filename: filename || 'index.html' });
    }
  }, [openUploadModal]);
  const randomAppKey = () => {
    const randomAppKey = nanoid(4) + nanoid(4);
    return randomAppKey;
  };
  const onSubmit = async (data: any) => {
    console.log(data);
    if (!text) {
      toast.error('代码不能为空');
      return;
    }
    if (!data.appKey) {
      toast.error('应用key不能为空');
      return;
    }
    if (!data.version) {
      toast.error('版本不能为空');
      return;
    }
    if (!data.filename) {
      toast.error('文件名不能为空');
      return;
    }
    setAppKey(data.appKey);
    setVersion(data.version);
    setFilename(data.filename);
    const res = await uploadFile({
      appKey: data.appKey,
      version: data.version,
      filename: data.filename,
      text,
    });
    if (res?.code === 200) {
      // toast.success('部署成功');
      const toastId = toast.loading('发布中...');
      await new Promise((resolve) => setTimeout(resolve, 2000));
      const res = await queryApp.publishVersion({ data: { appKey: data.appKey, version: data.version } });
      toast.dismiss(toastId);
      if (res?.code === 200) {
        toast.success('发布成功');
        setOpenSuccessModal(true);
      } else {
        toast.error(res?.message || '发布失败');
      }
    } else {
      toast.error(res?.message || '部署失败');
    }
  };
  return (
    <Modal open={openUploadModal} setOpen={setOpenUploadModal}>
      <div>
        <div>部署页面</div>
        <div className='text-sm text-gray-500 p-4'>
          <form className='flex flex-col gap-3 pt-1 ' onSubmit={handleSubmit(onSubmit)}>
            <div className='flex flex-col gap-1'>
              <label className='text-sm flex gap-2 items-center'>
                应用key
                <Tooltip title='随机生成应用key'>
                  <RefreshCcw
                    className='cursor-pointer w-4 h-4'
                    onClick={() => {
                      setValue('appKey', randomAppKey());
                    }}
                  />
                </Tooltip>
              </label>
              <Controller control={control} name='appKey' render={({ field }) => <Input {...field} />} />
            </div>
            <div className='flex flex-col gap-1'>
              <label className='text-sm'>版本</label>
              <Controller control={control} name='version' render={({ field }) => <Input {...field} />} />
            </div>
            <div className='flex flex-col gap-1'>
              <label className='text-sm'>文件名</label>
              <Controller control={control} name='filename' render={({ field }) => <Input {...field} />} />
            </div>
            <div className='flex justify-end gap-2 mt-3'>
              <Button
                onClick={() => {
                  setOpenUploadModal(false);
                }}>
                取消
              </Button>
              <Button type='submit'>提交</Button>
            </div>
          </form>
        </div>
      </div>
    </Modal>
  );
};
