import {
  DropdownMenu,
  DropdownMenuTrigger,
  DropdownMenuContent,
  DropdownMenuLabel,
  DropdownMenuSeparator,
  DropdownMenuItem,
} from '@/components/ui/dropdown-menu';
import { useEffect, useState } from 'react';
type Props = {
  children?: React.ReactNode;
  className?: string;
  options?: { label: string; value: string }[];
  onSelect?: (value: string) => void;
};

export const Menu = (props: Props) => {
  const [open, setOpen] = useState(false);
  const [selectedValue, setSelectedValue] = useState('');

  const handleSelect = (value: string) => {
    setSelectedValue(value);
    props.onSelect?.(value);
    setOpen(false);
  };
  const showSelectedValue = selectedValue || 'Select an option';
  return (
    <DropdownMenu open={open} onOpenChange={setOpen}>
      <DropdownMenuTrigger className={props.className}>{props.children ? props.children : showSelectedValue}</DropdownMenuTrigger>
      <DropdownMenuContent>
        {props.options?.map((option) => (
          <DropdownMenuItem key={option.value} onSelect={() => handleSelect(option.value)}>
            {option.label}
          </DropdownMenuItem>
        ))}
      </DropdownMenuContent>
    </DropdownMenu>
  );
};
